package entity

import (
	"time"
)

type FileMap map[string]File

func (m FileMap) Get(name string) File {
	if result, ok := m[name]; ok {
		return result
	}

	return File{FileName: name}
}

func (m FileMap) Pointer(name string) *File {
	if result, ok := m[name]; ok {
		return &result
	}

	return &File{FileName: name}
}

var FileFixtures = FileMap{
	"exampleFileName.jpg": {
		ID:              1000000,
		Photo:           PhotoFixtures.Pointer("19800101_000002_D640C559"),
		PhotoID:         PhotoFixtures.Pointer("19800101_000002_D640C559").ID,
		PhotoUID:        PhotoFixtures.Pointer("19800101_000002_D640C559").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96087uy",
		FileUID:         "ft8es39w45bnlqdw",
		FileName:        "2790/07/27900704_070228_D6D51B6C.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "Vacation/exampleFileNameOriginal.jpg",
		FileHash:        "2cad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        4278906,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       3648,
		FileHeight:      2736,
		FileOrientation: 0,
		FileProjection:  "equirectangular",
		FileAspectRatio: 1.33333,
		FileMainColor:   "green",
		FileColors:      "929299991",
		FileLuminance:   "8836BD496",
		FileDiff:        968,
		FileChroma:      25,
		FileError:       "",
		ModTime:         time.Date(2020, 3, 6, 2, 6, 51, 0, time.UTC).Unix(),
		Share: []FileShare{
			FileShareFixtures.Get("FileShare1", 0, 0, ""),
			FileShareFixtures.Get("FileShare2", 0, 0, ""),
		},
		Sync:      []FileSync{},
		CreatedAt: time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn: 414671279,
		UpdatedAt: time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn: 847648638,
		DeletedAt: nil,
	},
	"exampleDNGFile.dng": {
		ID:              1000001,
		Photo:           PhotoFixtures.Pointer("Photo01"),
		PhotoID:         PhotoFixtures.Pointer("Photo01").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo01").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080aa",
		FileUID:         "ft9es39w45bnlqdw",
		FileName:        "2790/02/Photo01.dng",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "3cad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        661858,
		FileCodec:       "jpeg",
		FileType:        "raw",
		FileMime:        "image/DNG",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "gold",
		FileColors:      "5552E2222",
		FileLuminance:   "444428399",
		FileDiff:        747,
		FileChroma:      12,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 3, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       414671279,
		UpdatedAt:       time.Date(2020, 3, 28, 14, 6, 0, 0, time.UTC),
		UpdatedIn:       847648638,
		DeletedAt:       nil,
	},
	"exampleXmpFile.xmp": {
		ID:              1000002,
		Photo:           PhotoFixtures.Pointer("Photo01"),
		PhotoID:         PhotoFixtures.Pointer("Photo01").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo01").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ab",
		FileUID:         "ft1es39w45bnlqdw",
		FileName:        "2790/02/Photo01.xmp",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "ocad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        858,
		FileCodec:       "",
		FileType:        "xmp",
		FileMime:        "",
		FilePrimary:     false,
		FileSidecar:     true,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       0,
		FileHeight:      0,
		FileOrientation: 0,
		FileProjection:  "",
		FileAspectRatio: 0,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 3, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       12361491,
		UpdatedAt:       time.Date(2020, 3, 28, 14, 6, 0, 0, time.UTC),
		UpdatedIn:       9537701,
		DeletedAt:       nil,
	},
	"bridge.jpg": {
		ID:              1000003,
		Photo:           PhotoFixtures.Pointer("Photo04"),
		PhotoID:         PhotoFixtures.Pointer("Photo04").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo04").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ac",
		FileUID:         "ft2es39w45bnlqdw",
		FileName:        "Germany/bridge.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        961858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       12361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       12361490,
		DeletedAt:       nil,
	},
	"reunion.jpg": {
		ID:              1000004,
		Photo:           PhotoFixtures.Pointer("Photo05"),
		PhotoID:         PhotoFixtures.Pointer("Photo05").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo05").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft3es39w45bnlqdw",
		FileName:        "2015/11/20151101_000000_51C501B5.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "2015/11/reunion.jpg",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        81858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "blue",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      4,
		FileError:       "Error",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       12361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       2361491,
		DeletedAt:       nil,
	},
	"Quality1FavoriteTrue.jpg": {
		ID:              1000005,
		Photo:           PhotoFixtures.Pointer("Photo17"),
		PhotoID:         PhotoFixtures.Pointer("Photo17").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo17").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ad",
		FileUID:         "ft4es39w45bnlqdw",
		FileName:        "1990/04/Quality1FavoriteTrue.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd819",
		FileSize:        500,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "blue",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      26,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       2361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       2361498,
		DeletedAt:       nil,
	},
	"missing.jpg": {
		ID:              1000006,
		Photo:           PhotoFixtures.Pointer("Photo15"),
		PhotoID:         PhotoFixtures.Pointer("Photo15").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo15").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ae",
		FileUID:         "ft5es39w45bnlqdw",
		FileName:        "1990/missing.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd819",
		FileSize:        500,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     true,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "blue",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      26,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       2361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       2361491,
		DeletedAt:       nil,
	},
	"Photo18.jpg": {
		ID:              1000007,
		Photo:           nil, // no pointer here because related photo is archived
		PhotoID:         1000018,
		PhotoUID:        "pt9jtdre2lvl0y25",
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080af",
		FileUID:         "ft6es39w45bnlqdw",
		FileName:        "Archived/Photo18.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd820",
		FileSize:        500,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       2361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       8361491,
		DeletedAt:       nil,
	},
	"Video.mp4": {
		ID:              1000008,
		Photo:           PhotoFixtures.Pointer("Photo10"),
		PhotoID:         PhotoFixtures.Pointer("Photo10").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo10").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ag",
		FileUID:         "ft71s39w45bnlqdw",
		FileName:        "Holiday/Video.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd831",
		FileSize:        7799202,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    17000000000,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Video.jpg": {
		ID:              1000014,
		Photo:           PhotoFixtures.Pointer("Photo10"),
		PhotoID:         PhotoFixtures.Pointer("Photo10").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo10").PhotoUID,
		InstanceID:      "",
		FileUID:         "fikjs39w45bnlqdw",
		FileName:        "Holiday/Video.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "abgt9168fa6acc5c5c2965ddf6ec465ca42fd831",
		FileSize:        7799202,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"VideoWithError.mp4": {
		ID:              1000009,
		Photo:           PhotoFixtures.Pointer("Photo10"),
		PhotoID:         PhotoFixtures.Pointer("Photo10").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo10").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ah",
		FileUID:         "ft72s39w45bnlqdw",
		FileName:        "Holiday/VideoError.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd832",
		FileSize:        500,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    17000000000,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "Error",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge1.jpg": {
		ID:              1000010,
		Photo:           PhotoFixtures.Pointer("Photo02"),
		PhotoID:         PhotoFixtures.Pointer("Photo02").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo02").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ai",
		FileUID:         "ft2es39q45bnlqd0",
		FileName:        "London/bridge1.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965ddf6ec465ca42fd828",
		FileSize:        961851,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge2.jpg": {
		ID:              1000011,
		Photo:           PhotoFixtures.Pointer("Photo03"),
		PhotoID:         PhotoFixtures.Pointer("Photo03").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo03").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080aj",
		FileUID:         "ft2es49w15bnlqdw",
		FileName:        "1990/04/bridge2.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd818",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge3.jpg": {
		ID:              1000012,
		Photo:           PhotoFixtures.Pointer("Photo03"),
		PhotoID:         PhotoFixtures.Pointer("Photo03").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo03").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080aj",
		FileUID:         "ft2es49whhbnlqdn",
		FileName:        "London/bridge3.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5ba965adf6ec465ca42fd818",
		FileSize:        921851,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge2.mp4": {
		ID:              1000013,
		Photo:           PhotoFixtures.Pointer("Photo03"),
		PhotoID:         1000003,
		PhotoUID:        PhotoFixtures.Pointer("Photo03").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080al",
		FileUID:         "ft2es49whhbnlqdy",
		FileName:        "1990/04/bridge2.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5ba965adf6ec465ca42fd819",
		FileSize:        921851,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "image/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    17000000000,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo19.jpg": {
		ID:              1000019,
		Photo:           PhotoFixtures.Pointer("Photo19"),
		PhotoID:         PhotoFixtures.Pointer("Photo19").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo19").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080am",
		FileUID:         "ft2es49qhhinlqdn",
		FileName:        "1990/04/Photo19.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd811",
		FileSize:        921831,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo25.jpg": {
		ID:              1000020,
		Photo:           PhotoFixtures.Pointer("Photo25"),
		PhotoID:         PhotoFixtures.Pointer("Photo25").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo25").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080an",
		FileUID:         "ft2es49qhhinlplk",
		FileName:        "2007/12/PhotoWithEditedAt.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd887",
		FileSize:        921831,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       2200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2007, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2007, 3, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo25_2.jpg": {
		ID:              1000021,
		Photo:           PhotoFixtures.Pointer("Photo25"),
		PhotoID:         PhotoFixtures.Pointer("Photo25").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo25").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ao",
		FileUID:         "ft2es49qhhinlpld",
		FileName:        "2007/12/PhotoWithEditedAt_2.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd895",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       2200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo27.jpg": {
		ID:              1000022,
		Photo:           PhotoFixtures.Pointer("Photo27"),
		PhotoID:         PhotoFixtures.Pointer("Photo27").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo27").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlple",
		FileName:        "2000/12/PhotoToBeBatchApproved2.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd896",
		FileSize:        900,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo27.mp4": {
		ID:              1000023,
		Photo:           PhotoFixtures.Pointer("Photo27"),
		PhotoID:         PhotoFixtures.Pointer("Photo27").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo27").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplf",
		FileName:        "2000/12/PhotoToBeBatchApproved2.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd897",
		FileSize:        900,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    1000000000,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo24.jpg": {
		ID:              1000024,
		Photo:           PhotoFixtures.Pointer("Photo24"),
		PhotoID:         PhotoFixtures.Pointer("Photo24").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo24").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplg",
		FileName:        "2020/vacation/PhotoMerge2.JPG",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd898",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo24.cr2": {
		ID:              1000025,
		Photo:           PhotoFixtures.Pointer("Photo24"),
		PhotoID:         PhotoFixtures.Pointer("Photo24").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo24").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplh",
		FileName:        "2020/vacation/PhotoMerge2.CR2",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd899",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "raw",
		FileMime:        "image/x-canon-cr2",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo23.jpg": {
		ID:              1000026,
		Photo:           PhotoFixtures.Pointer("Photo23"),
		PhotoID:         PhotoFixtures.Pointer("Photo23").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo23").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpli",
		FileName:        "2020/vacation/PhotoMerge.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd911",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo22.jpg": {
		ID:              1000027,
		Photo:           PhotoFixtures.Pointer("Photo22"),
		PhotoID:         PhotoFixtures.Pointer("Photo22").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo22").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplj",
		FileName:        "Mexico-With-Family/Photo22.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd912",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2010, 1, 1, 8, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 8, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo22-stack.jpg": {
		ID:              1000028,
		Photo:           PhotoFixtures.Pointer("Photo22"),
		PhotoID:         PhotoFixtures.Pointer("Photo22").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo22").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlolk",
		FileName:        "Mexico-Favorites/IMG-1234.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd913",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2010, 1, 1, 8, 5, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 8, 5, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo21.mp4.jpg": {
		ID:              1000029,
		Photo:           PhotoFixtures.Pointer("Photo21"),
		PhotoID:         PhotoFixtures.Pointer("Photo21").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo21").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpll",
		FileName:        "2018/01/20180101_130410_418COOO0.mp4.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd914",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo21.mp4": {
		ID:              1000030,
		Photo:           PhotoFixtures.Pointer("Photo21"),
		PhotoID:         PhotoFixtures.Pointer("Photo21").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo21").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplm",
		FileName:        "2018/01/20180101_130410_418COOO0.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "my-videos/IMG_88888.MP4",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd915",
		FileSize:        900,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    115000000000,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"FileWithoutPhoto.mp4": {
		ID:              1000031,
		PhotoUID:        "",
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpln",
		FileName:        "FileWithoutPhoto.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd916",
		FileSize:        900,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    115000000000,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo06.png": {
		ID:              1000032,
		Photo:           PhotoFixtures.Pointer("Photo06"),
		PhotoID:         PhotoFixtures.Pointer("Photo06").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo06").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplo",
		FileName:        "2016/11/Photo06.png",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd917",
		FileSize:        7799202,
		FileCodec:       "deflate/inflate",
		FileType:        "png",
		FileMime:        "image/png",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo06.jpg": {
		ID:              1000033,
		Photo:           PhotoFixtures.Pointer("Photo06"),
		PhotoID:         PhotoFixtures.Pointer("Photo06").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo06").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplp",
		FileName:        "2016/11/Photo06.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd918",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "white",
		FileColors:      "44444E449",
		FileLuminance:   "FFFFF2FF9",
		FileDiff:        1022,
		FileChroma:      8,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo07.heic": {
		ID:              1000034,
		Photo:           PhotoFixtures.Pointer("Photo07"),
		PhotoID:         PhotoFixtures.Pointer("Photo07").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo07").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplq",
		FileName:        "2016/11/Photo07.heic",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd918",
		FileSize:        199202,
		FileCodec:       "heic",
		FileType:        "heif",
		FileMime:        "image/heif",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo07.heic.jpg": {
		ID:              1000035,
		Photo:           PhotoFixtures.Pointer("Photo07"),
		PhotoID:         PhotoFixtures.Pointer("Photo07").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo07").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplr",
		FileName:        "2016/11/Photo07.heic.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd920",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "white",
		FileColors:      "44444E449",
		FileLuminance:   "FFFFF2FF9",
		FileDiff:        1022,
		FileChroma:      8,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo08.jpg": {
		ID:              1000036,
		Photo:           PhotoFixtures.Pointer("Photo08"),
		PhotoID:         PhotoFixtures.Pointer("Photo08").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo08").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpls",
		FileName:        "2016/11/Photo08.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd921",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo09.jpg": {
		ID:              1000036,
		Photo:           PhotoFixtures.Pointer("Photo09"),
		PhotoID:         PhotoFixtures.Pointer("Photo09").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo09").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplt",
		FileName:        "2016/11/Photo09.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd922",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo09(L).jpg": {
		ID:              1000037,
		Photo:           PhotoFixtures.Pointer("Photo09"),
		PhotoID:         PhotoFixtures.Pointer("Photo09").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo09").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplu",
		FileName:        "2016/11/Photo09(L).jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd923",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo11.jpg": {
		ID:              1000038,
		Photo:           PhotoFixtures.Pointer("Photo11"),
		PhotoID:         PhotoFixtures.Pointer("Photo11").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo11").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplv",
		FileName:        "2016/12/Photo11.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd924",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo12.jpg": {
		ID:              1000039,
		Photo:           PhotoFixtures.Pointer("Photo12"),
		PhotoID:         PhotoFixtures.Pointer("Photo12").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo12").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplx",
		FileName:        "2016/01/Photo12.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd925",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo13.jpg": {
		ID:              1000040,
		Photo:           PhotoFixtures.Pointer("Photo13"),
		PhotoID:         PhotoFixtures.Pointer("Photo13").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo13").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlply",
		FileName:        "2016/06/Photo13.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd926",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo14.jpg": {
		ID:              1000041,
		Photo:           PhotoFixtures.Pointer("Photo14"),
		PhotoID:         PhotoFixtures.Pointer("Photo14").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo14").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplz",
		FileName:        "2018/11/Photo14.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd927",
		FileSize:        8202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        534,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo16.jpg": {
		ID:              1000042,
		Photo:           PhotoFixtures.Pointer("Photo16"),
		PhotoID:         PhotoFixtures.Pointer("Photo16").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo16").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlrta",
		FileName:        "1990/Photo16.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd928",
		FileSize:        8402,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        234,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo20.jpg": {
		ID:              1000043,
		Photo:           PhotoFixtures.Pointer("Photo20"),
		PhotoID:         PhotoFixtures.Pointer("Photo20").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo20").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlrtb",
		FileName:        "1990/04/Photo20.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd929",
		FileSize:        6402,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        9934,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
}

var FileFixturesExampleJPG = FileFixtures["exampleFileName.jpg"]
var FileFixturesExampleXMP = FileFixtures["exampleXmpFile.xmp"]
var FileFixturesExampleBridge = FileFixtures["bridge.jpg"]
var FileFixturesExampleBridgeVideo = FileFixtures["bridge2.mp4"]

// CreateFileFixtures inserts known entities into the database for testing.
func CreateFileFixtures() {
	for _, entity := range FileFixtures {
		Db().Create(&entity)
	}
}
